import { HSL, HSV, RGB8, RGBF, XYZ } from '../interfaces/color-models';
/**
 * Converter from 8 bit RGB colour model representation into other supported colour models.
 * sRGB colour space with D65 white point is assumed.
 */
export declare class FromRGB8 {
    /**
     * Converts RGB8 object to RGBF.
     * @param {RGB8} rgb
     * @returns {RGBF}
     */
    static toRGBF(rgb: RGB8): RGBF;
    /**
     * Converts RGB 8 bit values to RGBF.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {RGBF}
     */
    static toRGBF(r: number, g: number, b: number): RGBF;
    /**
     * Converts RGB8 object to HSL.
     * @param {RGB8} rgb
     * @returns {HSL}
     */
    static toHSL(rgb: RGB8): HSL;
    /**
     * Converts RGB 8 bit values to HSL.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {HSL}
     */
    static toHSL(r: number, g: number, b: number): HSL;
    /**
     * Converts RGB8 object to HSV.
     * @param {RGB8} rgb
     * @returns {HSV}
     */
    static toHSV(rgb: RGB8): HSV;
    /**
     * Converts RGB 8 bit values to HSV.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {HSV}
     */
    static toHSV(r: number, g: number, b: number): HSV;
    /**
     * Converts RGB8 object to XYZ.
     * @param {RGB8} rgb
     * @returns {XYZ}
     */
    static toXYZ(rgb: RGB8): XYZ;
    /**
     * Converts RGB 8 bit values to XYZ.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {XYZ}
     */
    static toXYZ(r: number, g: number, b: number): XYZ;
    /**
     * Converts RGB8 object to hexadecimal representation.
     * @param {RGB8} rgb
     * @returns {string}
     */
    static toHex(rgb: RGB8): string;
    /**
     * Converts RGB 8 bit values to hexadecimal representation
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {string}
     */
    static toHex(r: number, g: number, b: number): string;
    private static resolveArguments(r, g?, b?);
}
