import { FromRGBF } from './rgbf';
import { HexHelper } from '../util/helpers';
/**
 * Converter from 8 bit RGB colour model representation into other supported colour models.
 * sRGB colour space with D65 white point is assumed.
 */
export class FromRGB8 {
    static toRGBF(r, g, b) {
        const args = FromRGB8.resolveArguments(r, g, b);
        return {
            r: args.r / 255,
            g: args.g / 255,
            b: args.b / 255
        };
    }
    static toHSL(r, g, b) {
        return FromRGBF.toHSL(FromRGB8.toRGBF(r, g, b));
    }
    static toHSV(r, g, b) {
        return FromRGBF.toHSV(FromRGB8.toRGBF(r, g, b));
    }
    static toXYZ(r, g, b) {
        return FromRGBF.toXYZ(FromRGB8.toRGBF(r, g, b));
    }
    static toHex(r, g, b) {
        const args = FromRGB8.resolveArguments(r, g, b);
        return `${HexHelper.numberToHex(args.r)}${HexHelper.numberToHex(args.g)}${HexHelper.numberToHex(args.b)}`;
    }
    static resolveArguments(r, g, b) {
        const argumentType = typeof r;
        let result;
        if (argumentType === 'object' && r !== null) {
            result = { r: r.r, g: r.g, b: r.b };
        }
        else if (argumentType === 'number') {
            result = { r: r, g: g, b: b };
        }
        else {
            throw new TypeError('Unknown arguments passed');
        }
        return result;
    }
}
