import { HSL, HSV, RGB8, RGBF, XYZ } from '../interfaces/color-models';
/**
 * Converter from float number RGB colour model representation into other supported colour models.
 * sRGB colour space with D65 white point is assumed.
 */
export declare class FromRGBF {
    /**
     * Converts RGBF object to RGB8.
     * @param {RGBF} rgb
     * @returns {RGB8}
     */
    static toRGB8(rgb: RGBF): RGB8;
    /**
     * Converts RGBF values to RGB8.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {RGB8}
     */
    static toRGB8(r: number, g: number, b: number): RGB8;
    /**
     * Converts RGBF object to HSL.
     * @param {RGBF} rgb
     * @returns {HSL}
     */
    static toHSL(rgb: RGBF): HSL;
    /**
     * Converts RGBF values to HSL.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {HSL}
     */
    static toHSL(r: number, g: number, b: number): HSL;
    /**
     * Converts RGBF object to HSV.
     * @param {RGBF} rgb
     * @returns {HSV}
     */
    static toHSV(rgb: RGBF): HSV;
    /**
     * Converts RGBF values to HSV.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {HSV}
     */
    static toHSV(r: number, g: number, b: number): HSV;
    /**
     * Converts RGBF object to XYZ.
     * @param {RGBF} rgb
     * @returns {XYZ}
     */
    static toXYZ(rgb: RGBF): XYZ;
    /**
     * Converts RGBF values to XYZ.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {XYZ}
     */
    static toXYZ(r: number, g: number, b: number): XYZ;
    private static resolveArguments(r, g?, b?);
}
